#
# spec file for package hardinfo2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           hardinfo2
Version:        2.1.11
Release:        1.0.2.1.sr20240605
Summary:        A System Information and Benchmark for Linux
License:        GPL-2.0-or-later AND LGPL-2.1-or-later AND LGPL-2.0-or-later AND GPL-3.0-or-later AND LGPL-2.1-only
Group:          System/Benchmark
URL:            https://www.hardinfo2.org/
Source0:        https://github.com/hardinfo2/hardinfo2/archive/release-%{version}/%{name}-release-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  openSUSE-release
BuildRequires:  pciutils
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(cairo-png)
BuildRequires:  pkgconfig(gmodule-export-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libsoup-3.0)
BuildRequires:  pkgconfig(zlib)
Recommends:     Mesa-demo-x
Recommends:     dmidecode
Recommends:     iperf
Recommends:     lsscsi
Recommends:     sensors
Recommends:     sysbench
Recommends:     udisks2
Recommends:     xdg-utils

%description
Hardinfo2 is based on hardinfo.

Hardinfo2 offers System Information and Benchmark for Linux Systems. It is able
to obtain information from both hardware and basic software. It can benchmark
your system and compare to other machines online.

Features include:
 - Report generation (in either HTML or plain text)
 - Online Benchmarking - compare your machine against other machines

%prep
%autosetup -p1 -n %{name}-release-%{version}

%build
%cmake \
    -DCMAKE_BUILD_TYPE=Release

%cmake_build

%install
%cmake_install

desktop-file-install --vendor="" \
  --set-generic-name='Hardware Information' \
  --add-category="Settings;HardwareSettings;" \
  --dir %{buildroot}%{_datadir}/applications %{buildroot}%{_datadir}/applications/%{name}.desktop

%fdupes %{buildroot}%{_datadir}

%find_lang %{name}

%files -f %{name}.lang
%doc README.md
%license LICENSE LICENSE.1 LICENSE.2
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/256x256/apps/hardinfo2.png
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Mon Jun  3 2024 Carsten Ziepke <kieltux@gmail.com>
- Update to version 2.1.11:
  * Fixed theme change not supporting native system settings
    theme setup.
  * Fixed background light/dark mode could be wrong depending
    on DE version
- Changes in version 2.1.8:
  * Fixed critical error - app was unreadable due to faulty
    dark mode detection
  * Added gsettings and dynamic darkmode for newer distros
- Changes in version 2.1.5:
  * PACKAGING: Recommends updated: add fwupd
  * Build updated to CMake 3.0.2 and more verbose/check during
    CPack builds
  * Build hardcoded prefix=/usr - we only build packages or
    install directly to package destination.
  * Fixed Translations not working in all distros/Packages
  * Fixed Memory Devices asked for root
  * Added loong64 as loongarch64 architecture
  * Added mips64el as mips architecture
  * Added Hungarian language
  * Minor: Fixed GCC warnings for modules/architectures, implicit
    function declarations, runtime warnings
* Mon May 20 2024 Carsten Ziepke <kieltux@gmail.com>
- Update to version 2.1.2:
  * Themes support added along with 6 themes for dark and
  light mode.
  * Memory_usage updated
  * UI/UX improved (Notes color scheme fixed for dark/light mode,
  scrollbars, sorting, string wrap, man page updated)
  * CLI - Skip benchmark reporting when -s (skip benchmark)
  * User Note for group benchmarks - more to come on this topic
  in user guide
  * Added network interface speed
  * Minor fixes - deprecated functions, gcc warning, runtime
  warning, implicit ctype functions, uninitialized variable
  * Fix Reload details after synchronize - M11
  * Fix frozen app window, focus loss every second time
  benchmarking - M13
  * Fix Benchmark shows too many records when not completed
  * Fix lowering flash in GUI benchmark for epileptics.
* Tue May 14 2024 Carsten Ziepke <kieltux@gmail.com>
- Initial version, based on the spec files from daviddavid (Mageia)
  and topazus (Fedora)
